@@ -1,6 +1,6 @@
 package Ubic;
 BEGIN {
-  $Ubic::VERSION = '1.28';
+  $Ubic::VERSION = '1.30';
 }
 
 use strict;
@@ -22,6 +22,7 @@ use Ubic::Multiservice::Dir;
 use Ubic::AccessGuard;
 use Ubic::Credentials;
 use Ubic::Persistent;
+use Ubic::AtomicFile;
 use Ubic::SingletonLock;
 use Ubic::Settings;
 
@@ -454,12 +455,9 @@ sub forked_call {
         };
 
         try {
-            open my $fh, '>', "$tmp_file.tmp" or die "Can't write to '$tmp_file.tmp: $!";
-            print {$fh} freeze($result);
-            close $fh or die "Can't close $tmp_file.tmp: $!";
+            Ubic::AtomicFile::store( freeze($result) => $tmp_file );
             STDOUT->flush;
             STDERR->flush;
-            rename "$tmp_file.tmp", $tmp_file;
             POSIX::_exit(0); # don't allow to lock to be released - this process was forked from unknown environment, don't want to run unknown destructors
         }
         catch {
@@ -497,7 +495,7 @@ Ubic - flexible perl-based service manager
 
 =head1 VERSION
 
-version 1.28
+version 1.30
 
 =head1 SYNOPSIS
 
@@ -521,13 +519,13 @@ This module is a perl frontend to ubic services.
 
 Further directions:
 
-if you are looking for a general introduction to Ubic, follow this link: L<http://blogs.perl.org/mt/mt-search.fcgi?blog_id=310&tag=tutorial&limit=20>;
+if you are looking for a general introduction to Ubic, see L<Ubic::Manual::Intro>;
 
 if you want to use ubic from command line, see L<ubic>;
 
 if you want to manage ubic services from perl scripts, read this POD;
 
-if you want to write your own service, see L<Ubic::Service> and other C<Ubic::Service::*> modules. Check out L<Ubic::Run> for integration with SysV init script system too.
+if you want to write your own service, see L<Ubic::Service> and other C<Ubic::Service::*> modules.
 
 =head1 CONSTRUCTOR
 
@@ -647,7 +645,7 @@ Get list of names of all services.
 
 Get root service.
 
-Root service doesn't have a name and returns all top-level services with C<services()> method. You can use it to traverse all services' tree.
+Root service doesn't have a name and returns all top-level services with C<services()> method. You can use it to traverse the whole service tree.
 
 =item B<compl_services($line)>
 
