@@ -1,6 +1,6 @@
 package Ubic::Admin::Setup;
 BEGIN {
-  $Ubic::Admin::Setup::VERSION = '1.28';
+  $Ubic::Admin::Setup::VERSION = '1.30';
 }
 
 # ABSTRACT: this module handles ubic setup: asks user some questions and configures your system
@@ -11,7 +11,9 @@ use warnings;
 
 use Getopt::Long 2.33;
 use Carp;
+use IPC::Open3;
 
+use Ubic::AtomicFile;
 use Ubic::Settings;
 use Ubic::Settings::ConfigFile;
 
@@ -87,6 +89,14 @@ sub xsystem {
     die join ", ", @msg;
 }
 
+sub slurp {
+    my ($file) = @_;
+    open my $fh, '<', $file or die "Can't open $file: $!";
+    my $result = join '', <$fh>;
+    close $fh;
+    return $result;
+}
+
 sub setup {
 
     my $opt_reconfigure;
@@ -243,9 +253,7 @@ sub setup {
             print "Installing ubic.$name service...\n";
 
             my $file = "$service_dir/ubic/$name";
-            open my $fh, '>', $file or die "Can't write to '$file': $!";
-            print {$fh} $content or die "Can't write to '$file': $!";
-            close $fh or die "Can't close '$file': $!";
+            Ubic::AtomicFile::store($content => $file);
         };
 
         $add_service->(
@@ -273,10 +281,16 @@ sub setup {
 
     if ($enable_crontab) {
         print "Installing cron jobs...\n";
-        my $old_crontab = qx(crontab -l);
-        if ($?) {
+
+        system("crontab -l >$data_dir/tmp/crontab.stdout 2>$data_dir/tmp/crontab.stderr");
+        my $old_crontab = slurp("$data_dir/tmp/crontab.stdout");
+        my $stderr = slurp("$data_dir/tmp/crontab.stderr");
+        unlink "$data_dir/tmp/crontab.stdout";
+        unlink "$data_dir/tmp/crontab.stderr";
+        if ($stderr and $stderr !~ /no crontab/) {
             die "crontab -l failed";
         }
+
         if ($old_crontab =~ /\subic-watchdog\b/) {
             print "Looks like you already have ubic commands in your crontab.\n";
         }
@@ -318,7 +332,7 @@ Ubic::Admin::Setup - this module handles ubic setup: asks user some questions an
 
 =head1 VERSION
 
-version 1.28
+version 1.30
 
 =head1 DESCRPITION
 
@@ -354,6 +368,10 @@ Ask user a yes/no question.
 
 Invoke C<system> command, throwing exception on errors.
 
+=item B<< slurp($file) >>
+
+Read file contents.
+
 =item B<< setup() >>
 
 Perform setup.
