@@ -1,6 +1,6 @@
 package Ubic::Daemon;
 BEGIN {
-  $Ubic::Daemon::VERSION = '1.28';
+  $Ubic::Daemon::VERSION = '1.30';
 }
 
 use strict;
@@ -346,7 +346,7 @@ sub check_daemon {
         return undef;
     }
     if ($guid eq $piddata->{guid}) {
-        warn "killing unguarded daemon '$daemon_cmd' with pid $piddata->{daemon} from $pidfile\n";
+        print "killing unguarded daemon '$daemon_cmd' with pid $piddata->{daemon} from $pidfile\n";
         kill -9 => $piddata->{daemon};
         $pid_state->remove;
         print "pidfile $pidfile removed\n";
@@ -371,7 +371,7 @@ Ubic::Daemon - toolkit for creating daemonized process
 
 =head1 VERSION
 
-version 1.28
+version 1.30
 
 =head1 SYNOPSIS
 
