@@ -1,6 +1,6 @@
 package Ubic::Persistent;
 BEGIN {
-  $Ubic::Persistent::VERSION = '1.29';
+  $Ubic::Persistent::VERSION = '1.30';
 }
 
 use strict;
@@ -11,6 +11,7 @@ use warnings;
 
 use JSON;
 use Ubic::Lockf;
+use Ubic::AtomicFile;
 
 {
     # JSON.pm v2 incompatibility with v1 is really, really annoying.
@@ -64,11 +65,8 @@ sub new {
 sub commit {
     my $self = shift;
     my $fname = $meta->{$self}{fname};
-    open my $tmp_fh, '>', "$fname.new" or die "Can't write '$fname.new': $!";
 
-    print {$tmp_fh} objToJson({ %$self });
-    close $tmp_fh or die "Can't write to '$fname.new': $!";
-    rename "$fname.new" => $fname or die "Can't rename '$fname.new' to '$fname': $!";
+    Ubic::AtomicFile::store(objToJson({ %$self }) => $fname);
 }
 
 sub DESTROY {
@@ -89,7 +87,7 @@ Ubic::Persistent - simple hash-to-file persistence object
 
 =head1 VERSION
 
-version 1.29
+version 1.30
 
 =head1 SYNOPSIS
 
